@@ -2,10 +2,26 @@ use v5.10;
 use Math::BigInt;
 use Scalar::Util 'blessed';
 
+unless (@ARGV) {
+    say "$0 number [to_warnbits]";
+    say;
+    say "Example usage:";
+    say "$0 0x55555555555555555555555555555500               --> 1902996923607946508077714625932660180412006400";
+    say "$0 1902996923607946508077714625932660180412006400 1 --> 0x55555555555555555555555555555500";
+    exit;
+}
+
 my $num = Math::BigInt->new( $ARGV[0] );
 
 # NOTE: FATAL codes also should mark the non-fatal bits, and MULTI bits should be included for all of them.
 
+# NF -> F  (in binary)
+# =======  ============
+#  0 -> 0  0000 -> 0000
+#  1 -> 3  0001 -> 0011
+#  4 -> C  0100 -> 1100
+#  5 -> F  0101 -> 1111
+
 unless ($ARGV[1]) {
    $num = byte_reverse($num);
    $num = bit_reverse($num);
@@ -31,7 +47,7 @@ sub byte_reverse ($) {
 
    $num = sprintf('%0128s', $num);
    $num = join('', map { scalar reverse } ($num =~ /(.{8})/g));
-   
+
    return Math::BigInt->new( '0b'.$num );
 }
 
